package MLDB_BTREE;
use strict;
use DB_File;
use MLDBM qw(DB_File);
use Fcntl;

sub new {
   my $proto = shift;
   my $class = ref($proto) || $proto;
   my $self = {
       file    => shift,
       DBM     => {},
   };
   bless ($self,$class);
   return $self;
}

$DB_BTREE->{'compare'} = \&sortcase;

sub sortcase {
    my ($key1, $key2) = @_;
    $key1 =~ s/\s*//g;
    $key2 =~ s/\s*//g;
    $key1 cmp $key2;
}

sub openr {
    my $self = shift;
    tie (%{$self->{DBM}}, 'MLDBM', $self->{file}, O_RDONLY, 0666, $DB_BTREE) || die $!;
}

sub closer {
    my $self = shift;
    untie %{$self->{DBM}};
}

sub openw {
    my $self = shift;
    my $append = shift;
    if ($append) {
	tie (%{$self->{DBM}}, 'MLDBM', $self->{file}, O_RDWR|O_CREAT, 0666, $DB_BTREE) || die $!;
    } else {
	tie (%{$self->{DBM}}, 'MLDBM', $self->{file}, O_RDWR|O_CREAT, 0666, $DB_BTREE) || die $!;
    }
}

sub closew {
    my $self = shift;
    untie %{$self->{DBM}};
}

sub exists {
    my $self = shift;
    my $entry = shift;
    return 1 if (exists ($self->{DBM}{$entry}));
    return 0;
}

sub get_files {
    my $self = shift;
    my @keys = keys %{$self->{DBM}};
    return @keys;
}

sub get_entry {
    my $self = shift;
    my $entry = shift;
    return $self->{DBM}{$entry};
}

sub write {
    my $self = shift;
    my $entry = shift;
    my $arrayref = shift;
    $self->{DBM}{$entry} = $arrayref;
}
1;


